<?php
/**
* NOTICE OF LICENSE
*
* This source file is subject to the Open Software License (OSL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/osl-3.0.php
*
*  @author    EveryPay
*  @copyright since 2015 EveryPay
*  @license   http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
*/
class SebPaymentGatewayValidationModuleFrontController extends ModuleFrontController
{
    public $ssl = true;
    public $display_column_left = false;
    private $paymentMethod = 'card';

    public function postProcess()
    {
        if (Tools::getValue('payment_method')) {
            if (Tools::getValue('payment_method') === 'bank') {
                $this->paymentMethod = Tools::getValue('selected_provider');
            } else {
                $this->paymentMethod = Tools::getValue('payment_method');
            }
        }
        $cart = $this->context->cart;
        if ($cart->id_customer == 0 ||
            $cart->id_address_delivery == 0 ||
            $cart->id_address_invoice == 0 ||
            !$this->module->active
        ) {
            Tools::redirect('index.php?controller=order&step=1');
        }
        // Check that this payment option is still available in case the
        // customer changed his address just before the end of the checkout process
        $authorized = false;
        foreach (Module::getPaymentModules() as $module) {
            if ($module['name'] == 'sebpaymentgateway') {
                $authorized = true;
                break;
            }
        }
        if (!$authorized) {
            die($this->module->l('This payment method is not available.', 'validation'));
        }
        $customer = new Customer($cart->id_customer);
        if (!Validate::isLoadedObject($customer)) {
            Tools::redirect('index.php?controller=order&step=1');
        }

        if (Configuration::get($this->module->formatName('create_order')) === 'before') {
            $currency = $this->context->currency;
            $total = (float)$cart->getOrderTotal(true, Cart::BOTH);
            $mailVars = array(
                // '{bankwire_owner}' => Configuration::get('BANK_WIRE_OWNER'),
                // '{bankwire_details}' => nl2br(Configuration::get('BANK_WIRE_DETAILS')),
                // '{bankwire_address}' => nl2br(Configuration::get('BANK_WIRE_ADDRESS'))
            );
            $customerWasLogged = $this->context->customer->isLogged(); // validateOrder() sets to 0, restore this later
            $this->module->validateOrder(
                $cart->id,
                Configuration::get('PS_OS_SEBPAYMENTGATEWAY'),
                $total,
                $this->module->getFormattedPaymentMethod (Tools::getValue('payment_method') ? Tools::getValue('payment_method') : 'missing_payment_method'),
                //$this->module->l('Card payment', 'validation'),
                null,
                $mailVars,
                (int)$currency->id,
                false,
                $customer->secure_key
            );
            $this->context->customer->logged = $customerWasLogged;
        }
    }
    public function initContent()
    {
        parent::initContent();

        include $this->module->getLocalPath().'lib/sebpaymentgateway_library.php';
        include $this->module->getLocalPath().'lib/CardStorageLibrary.php';
                
        if (Configuration::get($this->module->formatName('create_order')) != 'before') {
            $cart = $this->context->cart;
            $order_ref = $cart->id;
            $order_amount =  Tools::ps_round((float)$cart->getOrderTotal(true, Cart::BOTH), 2);
        } elseif ($this->module->currentOrder) {
            $order = new Order((int)$this->module->currentOrder);
            $order_ref = $order->reference;
            $order_amount =  Tools::ps_round($order->total_paid, 2);
        }
        if ($this->module->currentOrder ||
            Configuration::get($this->module->formatName('create_order')) != 'before'
        ) {
            $address_delivery = new Address($this->context->cart->id_address_delivery, $this->context->language->id);
            $address_invoice = new Address($this->context->cart->id_address_invoice, $this->context->language->id);
            if (Configuration::get($this->module->formatName('live_mode'))) {
                if ('apple_pay' === $this->paymentMethod) {
                    $sebpaymentgateway_url = Configuration::get($this->module->formatName('apple_pay_v4_production_url'));
                } else {
                    $sebpaymentgateway_url = Configuration::get($this->module->formatName('production_url'));
                }
                $sebpaymentgateway_library = new SebPaymentGatewayLibrary();
                $sebpaymentgateway_library->init(
                    Configuration::get($this->module->formatName('api_username')),
                    Configuration::get($this->module->formatName('shared_secret'))
                );
            } else {
                if ('apple_pay' === $this->paymentMethod) {
                    $sebpaymentgateway_url = Configuration::get($this->module->formatName('apple_pay_v4_demo_url'));
                } else {
                    $sebpaymentgateway_url = Configuration::get($this->module->formatName('demo_url'));
                }
                $sebpaymentgateway_library = new SebPaymentGatewayLibrary();
                $sebpaymentgateway_library->init(
                    Configuration::get($this->module->formatName('test_api_username')),
                    Configuration::get($this->module->formatName('test_shared_secret'))
                );
            }
            $skinName = Configuration::get($this->module->formatName('iframe_skin'));
            if (empty($skinName)) {
                $skinName = "default";
            }
            $this->context->smarty->assign($queryFields = array(
                'amount' => $order_amount,
                'account_name' => Configuration::get($this->module->formatName('account_id')),
                'billing_city' => $address_invoice->city,
                'billing_country' => Country::getIsoById((int)$address_invoice->id_country),
                'billing_state' => Country::getNameById(Context::getContext()->language->id, (int)$address_invoice->id_country),
                'billing_postcode' => $address_invoice->postcode,
                'billing_line1' => $address_invoice->address1,
                'billing_line2' => $address_invoice->address2 ? $address_invoice->address2 : "-",
                'billing_line3' => '-',
                'customer_url' => $this->context->link->getModuleLink('sebpaymentgateway', 'customerReturn', array(), true),
                'shipping_city' => $address_delivery->city,
                'shipping_country' => Country::getIsoById((int)$address_delivery->id_country),
                'shipping_code' => $address_delivery->postcode,
                'shipping_line1' => $address_delivery->address1,
                'shipping_line2'=> $address_delivery->address2 ? $address_delivery->address2 : "-",
                'shipping_line3' => '',
                'email' => $this->context->customer->email,
                'order_reference' => $order_ref,
                'customer_ip' => $_SERVER['REMOTE_ADDR'],
            ));

            if (Configuration::get($this->module->formatName('token_payment')) && $this->context->customer->isLogged()) {
                $queryFields['request_token'] = true;
                $queryFields['token_agreement'] = 'unscheduled';
            }

            if ($this->isTokenPayment()) {
                $id_card = $this->getCardId();
                $card = new CardStorageLibrary($id_card);
                if (isset($card->id_customer) && $card->id_customer == $this->context->customer->id) {
                    $queryFields['token'] = $card->token;
                }
                $sebpaymentgateway_url .= 'cit';
            } else {
                $sebpaymentgateway_url .= 'oneoff';
            }

            if (Tools::strtolower(Tools::getValue('response_type')) == "json") {
                $queryFields['skin_name'] = $skinName;
            }
            if ('apple_pay' === $this->paymentMethod) {
                $queryFields['mobile_payment'] = true;
            }

            $data = $sebpaymentgateway_library->getFields(
                $queryFields,
                Tools::strtolower($this->context->language->iso_code)
            );

            if (Tools::strtolower(Tools::getValue('response_type')) == "json") {
                if ($this->paymentMethod == 'card') {
                    $data['customer_url'] = $this->context->link->getModuleLink('sebpaymentgateway', 'customerReturn', array(
                        "content_only" => 1
                    ), true);
                }
                $response = $this->sendPaymentRequest($sebpaymentgateway_url, $data, $sebpaymentgateway_library->getAPIUsername(),
                    $sebpaymentgateway_library->getAPISecret(), true);
                if (SebPaymentGateway::DEBUG_LOGGING) {
                    $this->module->logError(array('response' => $response, 'payload' => $data), 'Validate::sendPaymentRequest() - json');
                }
                die($response);
            } else {
                $response = $this->sendPaymentRequest($sebpaymentgateway_url, $data, $sebpaymentgateway_library->getAPIUsername(), $sebpaymentgateway_library->getAPISecret(), false);
                if (SebPaymentGateway::DEBUG_LOGGING) {
                    $this->module->logError(array('response' => $response, 'payload' => $data), 'Validate::sendPaymentRequest() ');
                }
                if (isset($response['cc_details']) && $response['payment_link']) {
                    Tools::redirect($response['payment_link']);
                } elseif ($paymentLink = $this->getPaymentLinkFromResponseByPaymentMethod($this->paymentMethod, $response)) {
                    Tools::redirect($paymentLink);
                } else {
                    Tools::redirect('index.php?controller=order&step=1');
                }
                /*$this->context->smarty->assign(array(
                    'sebpaymentgateway_url' => $sebpaymentgateway_url
                ));
                $this->context->smarty->assign(array(
                    'payment_link' => $response['payment_link']
                ));
                $this->context->smarty->assign($data);
                $this->setTemplate('module:sebpaymentgateway/views/templates/front/validation.tpl');*/

            }
        } else {
            Tools::redirect('index.php?controller=order&step=1');
        }
    }

    private function isTokenPayment() {
        if (Tools::getIsset('card_choice') && Tools::getValue('card_choice') !== 'new') {
            return true;
        }
        if (Tools::getIsset('sebPaymentGatewayChoice') && Tools::getValue('sebPaymentGatewayChoice') !== 'new') {
            return true;
        }

        return false;
    }

    private function getCardId() {
        if (Tools::getIsset('card_choice')) {
            return (int) Tools::getValue('card_choice');
        }

        return (int) Tools::getValue('sebPaymentGatewayChoice');
    }

    private function sendPostRequestWithBasicAuth($url, $data, $username, $password) {
        $request_body = json_encode($data);
        $ch = curl_init($url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLINFO_HEADER_OUT, true);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $request_body);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
                'Content-Type: application/json',
                'Accept: application/json',
                'Content-Length: ' . strlen($request_body))
        );
        curl_setopt($ch, CURLOPT_USERPWD, $username . ":" . $password);
        $response = curl_exec($ch);
        curl_close($ch);
        return $response;
    }

    private function sendPaymentRequest($url, $data, $username, $password, /*$order_reference,*/ $isJsonResponse) {
        $response = $this->sendPostRequestWithBasicAuth($url, $data, $username, $password);
        $responseAssoc = json_decode($response, true);
        //$this->savePaymentReference($order_reference, $responseAssoc["payment_reference"]);
        return $isJsonResponse ? $response : $responseAssoc;
    }

    // Not used at the moment because Everypay API now sends payment_reference as GET parameter to customer_url
    private function savePaymentReference($order_reference, $payment_reference) {
        $existingPaymentSql = new DbQuery();
        $existingPaymentSql->select("*");
        $existingPaymentSql->from("sebpaymentgateway_payments");
        $existingPaymentSql->where("order_reference = " . (int) $order_reference);
        $existingPayment = Db::getInstance()->executeS($existingPaymentSql);
        if ($existingPayment) {
            $this->updatePaymentsTableRow($order_reference, $payment_reference);
        } else {
            $this->insertIntoPaymentsTable($order_reference, $payment_reference);
        }
    }

    private function insertIntoPaymentsTable($order_reference, $payment_reference) {
        Db::getInstance()->insert("sebpaymentgateway_payments", array(
            "order_reference" => $order_reference,
            "payment_reference" => $payment_reference
        ));
    }

    private function updatePaymentsTableRow($order_reference, $payment_reference) {
        Db::getInstance()->update("sebpaymentgateway_payments", array(
            "payment_reference" => $payment_reference
        ), "order_reference = " . $order_reference);
    }

    private function getPaymentLinkFromResponseByPaymentMethod($paymentMethod, $response) {
        if (isset($response['payment_methods'])) {
            foreach ($response['payment_methods'] as $method) {
                if ($method['payment_link'] && $method['source'] == $paymentMethod) return $method['payment_link'];
            }
        }
        return false;
    }

}
