/*
 * NOTICE OF LICENSE
 *
 * This file is licenced under the Software License Agreement.
 * With the purchase or the installation of the software in your application
 * you accept the licence agreement.
 *
 * You must not modify, adapt or create derivative works of this source code
 *
 *  @author    EveryPay
 *  @copyright since 2015 EveryPay
 *  @license   LICENSE.txt
 */
"use strict";
var SEBPAYMENTGATEWAY = {};
SEBPAYMENTGATEWAY.id = 'sebpaymentgateway';
SEBPAYMENTGATEWAY.iframeVisible = 0;
SEBPAYMENTGATEWAY.managingCards = 0;
SEBPAYMENTGATEWAY.retry_redirect = window.sebpaymentgateway_checkout_params.retry_redirect;

window.addEventListener('load', function() {
    SEBPAYMENTGATEWAY.init();
});

SEBPAYMENTGATEWAY.init = function(){
    SEBPAYMENTGATEWAY.selectedBanklinkSource = SEBPAYMENTGATEWAY.getDefaultSelectedBanklinkSource();

    SEBPAYMENTGATEWAY.changeCard();

    SEBPAYMENTGATEWAY.removeEmptyBankLinkSelectCountryOptions();

    SEBPAYMENTGATEWAY.setSelectCountry(); // task 17971 - checks and sets selected drop down country as delivery address country

    SEBPAYMENTGATEWAY.removeLoadingIndicator();

    // task 17972
    SEBPAYMENTGATEWAY.attachRadioListeners();

    SEBPAYMENTGATEWAY.attachButtonClickEvent();

    //var termsCheckbox = $('#conditions_to_approve[terms-and-conditions]');
    var termsCheckbox = document.getElementById('conditions_to_approve[terms-and-conditions]');
    attachlistenersSEB(termsCheckbox);
};

SEBPAYMENTGATEWAY.storeData = function(data) {
    if (!sessionStorage.getItem(SEBPAYMENTGATEWAY.id)) {
        sessionStorage.setItem(SEBPAYMENTGATEWAY.id, JSON.stringify({}));
    }
    const storedData = JSON.parse(sessionStorage.getItem(SEBPAYMENTGATEWAY.id));
    for (let dataKey in data) {
        storedData[dataKey] = data[dataKey];
    }

    sessionStorage.setItem(SEBPAYMENTGATEWAY.id, JSON.stringify(storedData));
}

// Get the selector for the 'Place Order' button.
SEBPAYMENTGATEWAY.getPlaceOrderButtonSelector = function() {
    return '#payment-confirmation button, #tc-payment-confirmation button';
}

SEBPAYMENTGATEWAY.disablePlaceOrderButton = function() {
    document.querySelector(SEBPAYMENTGATEWAY.getPlaceOrderButtonSelector()).disabled = true;
}

// 'Click' event for the PrestaShop default 'Place Order' button, when the Bank option is selected.
SEBPAYMENTGATEWAY.attachButtonClickEvent = function() {
    let placeOrderButton = $(SEBPAYMENTGATEWAY.getPlaceOrderButtonSelector());
    if (!placeOrderButton) {
        return;
    }
    placeOrderButton.on('click', function(e) {
        if (SEBPAYMENTGATEWAY.isSelectedPaymentMethod('bank')) {
            if (!SEBPAYMENTGATEWAY.selectedBanklinkSource) {
                SEBPAYMENTGATEWAY.toggleBankOptionHighlighting(true);
                preventDefaultBehaviour(e);
                return;
            }
        }

        placeOrderIframe(e, 'card');
        placeOrderIframe(e, 'paypal');

        function placeOrderIframe(e, methodId) {
            if (SEBPAYMENTGATEWAY.isSelectedPaymentMethod(methodId)) {
                preventDefaultBehaviour(e);
                SEBPAYMENTGATEWAY.disablePlaceOrderButton();
                SEBPAYMENTGATEWAY.open(methodId);
            }
        }

        function preventDefaultBehaviour(e) {
            e.preventDefault();
            e.stopImmediatePropagation();
        }
    });
}

// Check if the given payment method is selected
SEBPAYMENTGATEWAY.isSelectedPaymentMethod = function(methodId) {
    return $('.' + SEBPAYMENTGATEWAY.id + '-form-iframe-' + methodId + ':visible').length > 0;
}

SEBPAYMENTGATEWAY.getDefaultSelectedBanklinkSource = function() {
    const storedData = JSON.parse(sessionStorage.getItem(SEBPAYMENTGATEWAY.id));
    if (!storedData || !storedData.selected_provider) {
        return undefined;
    }

    return storedData.selected_provider;
}

SEBPAYMENTGATEWAY.displayBankLinkPaymentMethods = function(countryCode) {
    if (!countryCode) {
        return;
    }
    const bankLists = document.querySelectorAll('.sebpaymentgateway_banklinks_list');
    bankLists.forEach(function(list) {
        if (list.classList.contains(countryCode)) {
            list.style.display = 'flex';
        } else {
            list.style.display = 'none';
        }
    });
};

SEBPAYMENTGATEWAY.uncheckBankLinks = function () {
    const links = document.querySelectorAll('.sebpaymentgateway_banklink_container input');
    links.forEach(function(link) {
        link.checked = false;
    });
}

SEBPAYMENTGATEWAY.removeEmptyBankLinkSelectCountryOptions = function() {
    if(!($('#sebpaymentgatewayBanklinkCountrySelect').length)) {
        return;
    }
    $('#sebpaymentgatewayBanklinkCountrySelect > option').each(function() {
        const bankContainer = document.querySelectorAll('.sebpaymentgateway_banklinks_list.' + this.value + ' > .sebpaymentgateway_banklink_container');
        if (bankContainer.length === 0) {
            this.remove();
        }
    });
};

// task 17971 sets selected country as cart delivery address country
SEBPAYMENTGATEWAY.setSelectCountry = function () {
    if(!($('#sebpaymentgatewayBanklinkCountrySelect').length) || SEBPAYMENTGATEWAY.getDefaultSelectedBanklinkSource()) {
        return;
    }
    var customerCountry = 'EE';
    if (sebpaymentgatewayIdAddressDelivery === undefined || sebpaymentgatewayIdAddressDelivery === null) {
        // pass
    } else {
        customerCountry = (prestashop.customer.addresses[sebpaymentgatewayIdAddressDelivery].country_iso ?
            prestashop.customer.addresses[sebpaymentgatewayIdAddressDelivery].country_iso : 'EE');
    }
    $('#sebpaymentgatewayBanklinkCountrySelect > option').each(function () {
        if (this.value === customerCountry) {
            $('#sebpaymentgatewayBanklinkCountrySelect').val(this.value);
            SEBPAYMENTGATEWAY.processCountrySelectChange();
        }
    });
};

// task 17972
SEBPAYMENTGATEWAY.enableLinks = function () {
    if(!($('.js-payment-sebpaymentgateway').length)) {
        console.log('a');
        return;
    }
    $('.js-payment-sebpaymentgateway').each(function () {
        // todo possibly add conditions
        if (1 === 1/*this.value === customerCountry*/) {
            $(this).removeClass('disabled');
        }
    });
};

// task 17972 - this restores payment options visibility after they being hidden by PS if terms checkbox is not checked atm
SEBPAYMENTGATEWAY.attachRadioListeners = function () {
    var sebpaymentgatewayRadioOptions = document.getElementsByName("payment-option");
    sebpaymentgatewayRadioOptions.forEach((option) => {
        if (option.getAttribute('data-module-name') === 'sebpaymentgateway') {
            option.addEventListener("change", async function () {
                await SEBPAYMENTGATEWAY.sleep(100);
                SEBPAYMENTGATEWAY.enableLinks();
            }, false);
        }
    });
};

// task 17972 // this is used to attach listeners to terms checkbox to make banklinks visible on terms status change and to change pay button style
function attachlistenersSEB(element) {
    if (!element) {
        return;
    }
    element.addEventListener("change", async function() {
        await SEBPAYMENTGATEWAY.sleep(100);
        SEBPAYMENTGATEWAY.enableLinks();}
    );
}

// task 17972
SEBPAYMENTGATEWAY.sleep = function (ms) {
    return new Promise(resolve => setTimeout(resolve, ms));
};

// task 17972
SEBPAYMENTGATEWAY.areTermsAccepted = function () {
    let checkBoxStatus = document.getElementById('conditions_to_approve[terms-and-conditions]');
    if (!checkBoxStatus) {
        return false;
    } else {
        return checkBoxStatus.checked;
    }
};

SEBPAYMENTGATEWAY.processCountrySelectChange = function() {
    if(!($('#sebpaymentgatewayBanklinkCountrySelect').length)) {
        return;
    }
    SEBPAYMENTGATEWAY.changeSelectedBanklinkSource(undefined); // this resets saved payment source on country change
    let selectedCountry = $('#sebpaymentgatewayBanklinkCountrySelect').val();
    SEBPAYMENTGATEWAY.storeData({selected_country: selectedCountry});
    SEBPAYMENTGATEWAY.displayBankLinkPaymentMethods(selectedCountry);
    SEBPAYMENTGATEWAY.uncheckBankLinks();
};

SEBPAYMENTGATEWAY.startPayment = function (source) {
    if (source !== "card" || source !== "paypal") {
        $("body").css("cursor", "progress");
    }
    var saveCardChecked = ($('.saveCardOption input[type="checkbox"]:checked').length !== 0 ? 1 : 0);
    var iframe = $('.sebpaymentgatewayIframe');
    let requestData = {
        saveCard: saveCardChecked,
        payment_method: source
    };
    if (source === 'card') requestData.card_choice = $('input[name="sebPaymentGatewayChoice"]:checked').val();
    $.ajax({
        url: iframe.attr("target-url") + "?fc=module&module=sebpaymentgateway&controller=validation&response_type=json",
        dataType: "json",
        data: requestData,
        method: "POST",
        success: function (data) {
            SEBPAYMENTGATEWAY.order_reference = data.order_reference;
            if (SEBPAYMENTGATEWAY.retryRedirect) {
                SEBPAYMENTGATEWAY.retryRedirect = SEBPAYMENTGATEWAY.retryRedirect.replace("ORDER_REFERENCE", data.order_reference);
            }
            if (source === "card" || source === 'paypal') {
                let paymentLink = undefined;
                if (typeof data.cc_details !== 'undefined') {
                    paymentLink = data.payment_link;
                } else {
                    paymentLink = SEBPAYMENTGATEWAY.getPaymentMethodInfo(source, data.payment_methods)["payment_link"];
                }
                SEBPAYMENTGATEWAY.paymentLinkToIframe(paymentLink, source);
            } else {
                window.location = SEBPAYMENTGATEWAY.getPaymentMethodInfo(source, data.payment_methods)["payment_link"];
            }
        },
        error: function () {
            if (source === "card") {
                var doc = iframe[0].contentWindow.document;
                var $body = $('body', doc);
                $body.html("<p>Cannot get payment page</p>");
                $body.css({"text-align": "center"});
            }
            $("body").css("cursor", "default");
        }
    });
};

SEBPAYMENTGATEWAY.open = function(paymentMethod){
    SEBPAYMENTGATEWAY.startPayment(paymentMethod);
    $('.row').each(function(){
      if ($(this).find('.payment_module').length >= 1 && !$(this).find('.payment_module').hasClass('sebpaymentgateway')) $(this).hide(2000);
    });
    SEBPAYMENTGATEWAY.openIframe(paymentMethod);

//MANAGE CARDS START
   /*var saveCardChecked = ($('.saveCardOption input[type="checkbox"]:checked').length !== 0 ? 1 : 0);
   var iframe = $('#sebpaymentgatewayIframe');
   $.ajax({
      url:iframe.attr("target-url")+"?fc=module&module=sebpaymentgateway&controller=validation&response_type=json",
      dataType:"json",
      data:{card_choice:$('input[name="sebpaymentgatewayChoice"]:checked').val(), saveCard:saveCardChecked},
      method:"POST",
      success:function(data) {
            SEBPAYMENTGATEWAY.order_reference = data.order_reference;
            SEBPAYMENTGATEWAY.retryRedirect = SEBPAYMENTGATEWAY.retryRedirect.replace("ORDER_REFERENCE", data.order_reference);
            SEBPAYMENTGATEWAY.paymentLinkToIframe(SEBPAYMENTGATEWAY.getPaymentMethodInfo("card", data.payment_methods)["payment_link"]);
      },
       error:function() {
           var doc = iframe[0].contentWindow.document;
           var $body = $('body',doc);
           $body.html("<p>Cannot get payment page</p>");
           $body.css({"text-align": "center"});
       }
   });*/
};

SEBPAYMENTGATEWAY.getPaymentMethodInfo = function(source, payment_methods) {
    for (var i = 0; i < payment_methods.length; i++) {
        if (payment_methods[i].source === source) return payment_methods[i];
    }
};

SEBPAYMENTGATEWAY.paymentLinkPageToIframe = function(paymentLink) {
    if ($('#sebpaymentgatewayForm').length > 0) $('#sebpaymentgatewayForm').remove();
    $('#sebpaymentgatewayIframe').parent().append('<form method="post" action="'+paymentLink+'" id="sebpaymentgatewayForm"></form>');
    $('#sebpaymentgatewayForm').attr("target", "SEBPAYMENTGATEWAYIFRAME");
    $('#sebpaymentgatewayForm').submit();
};

SEBPAYMENTGATEWAY.paymentLinkToIframe = function(paymentLink, paymentMethod) {
    var $iframe = $("#" + paymentMethod + "-iframe" + "-SEB");
    $iframe.attr("src", paymentLink);
};

SEBPAYMENTGATEWAY.deleteCard = function(obj){
   if (confirm(window.sebpaymentgateway_checkout_params.sebpaymentgateway_delete_txt)) {
      var link = $(obj).attr('data-remove-card-link');
      $.ajax({
          url:link,
          success:$(obj).parent().remove()
      }).done(function(){
            $('#checkout-payment-step').addClass('-current js-current-step');
            if($('.sebpaymentgatewayOption').length < 1){
                $('.sebpaymentgatewayChoices').find('.sebpaymentgatewayManagecards').addClass('hidden');
            }
      });
   }
};

SEBPAYMENTGATEWAY.setDefault = function(obj){
    var link = $(obj).attr('data-set-default-link');
    $.ajax({
        url:link
    });
    $(obj).parent().find('.makeDefault').removeClass('manageCardUI').hide();
    $('.sebpaymentgatewayOption.default').removeClass('default').find('.makeDefault').addClass('manageCardUI').show();
    $(obj).parent().addClass('default');
};

SEBPAYMENTGATEWAY.changeCard = function(){
   if ($('input[name="sebpaymentgatewayChoice"][value="new"]:checked').length !== 0) {
      $('.saveCardOption').show();
   } else {
      $('.saveCardOption').hide();
   }
};

SEBPAYMENTGATEWAY.manageCardsToggle = function(){
   if (SEBPAYMENTGATEWAY.managingCards){
      $('.manageCardUI').hide();
      SEBPAYMENTGATEWAY.managingCards = 0;
   }else{
      $('.manageCardUI').show();
      SEBPAYMENTGATEWAY.managingCards = 1;
   }
};
//MANAGE CARDS END

SEBPAYMENTGATEWAY.closeIframe = function(){
   SEBPAYMENTGATEWAY.iframeVisible = 0;
   $( "#sebpaymentgatewayIframe" ).show().removeClass('visible iframe-padding').animate({
        height: "0px"
    }, 500);
   $('.sebpaymentgatewayUI').show();
};

SEBPAYMENTGATEWAY.openIframe = function(paymentMethod){
    var paymentModuleContainerSelector = "." + paymentMethod + "-payment-container";
    $(paymentModuleContainerSelector).css('width', '358px');
    $(paymentModuleContainerSelector).css('height', '570px');
    $( "#" + paymentMethod + "-iframe" + "-SEB" ).show().addClass('visible iframe-padding').animate({
        width: "358px",
        height: "650px"
    }, 500);
   $('.sebpaymentgatewayUI').hide();
   SEBPAYMENTGATEWAY.setLoadingIndicatorToIframe(paymentMethod);
   SEBPAYMENTGATEWAY.iframeVisible = 1;
};

SEBPAYMENTGATEWAY.setLoadingIndicatorToIframe = function(paymentMethod) {
    var $iframe = $('#' + paymentMethod + '-iframe' + '-SEB');
    var doc = $iframe[0].contentWindow.document;
    var $body = $('body', doc);
    $body.html('<img class="loadingIndicator" src="/modules/sebpaymentgateway/views/img/loader.gif"/>');
    $body.css({"text-align": "center"});
};

SEBPAYMENTGATEWAY.removeLoadingIndicator = function() {
    $(".loadingIndicator").remove();
};

SEBPAYMENTGATEWAY.reclose = function(){
   if ($('#sebpaymentgatewayIframe').attr('order-create-method') != "after") {
      window.location=SEBPAYMENTGATEWAY.retryRedirect;
   } else {
        $('#sebpaymentgatewayRetryButton').hide();
        $('.row').each(function(){
            if ($(this).find('.payment_module').length >= 1 && !$(this).find('.payment_module').hasClass('sebpaymentgateway')) $(this).show(2000);
        });
        SEBPAYMENTGATEWAY.closeIframe();
        setTimeout("$('.sebpaymentgatewayRedirect.button').show();", 2000);
   }
};

SEBPAYMENTGATEWAY.createQuery = function(data){
    if ($('#sebpaymentgatewayForm').length > 0) $('#sebpaymentgatewayForm').remove();
    $('#sebpaymentgatewayIframe').parent().append('<form method="post" action="'+data.sebpaymentgateway_url+'" id="sebpaymentgatewayForm"></form>');
    var i = 0;
    while (i < data.data.length) {
        $('#sebpaymentgatewayForm').append("<input type='hidden' name='"+data.data[i].key+"' value='"+data.data[i].value+"'>");
        i++;
    }
    $('#sebpaymentgatewayForm').attr("target", "SEBPAYMENTGATEWAYIFRAME");
    $('#sebpaymentgatewayForm').submit();
};

SEBPAYMENTGATEWAY.changeSelectedBanklinkSource = function(source) {
    SEBPAYMENTGATEWAY.storeData({selected_provider: source});
    $('.sebpaymentgateway-bank #bank_selected_provider').val(source);
    this.selectedBanklinkSource = source;
};

// added checking for disabled condition in task 17972
SEBPAYMENTGATEWAY.startBanklinkPayment = function() {
    if (!SEBPAYMENTGATEWAY.selectedBanklinkSource) {
        SEBPAYMENTGATEWAY.toggleBankOptionHighlighting(true);
        return;
    }
    SEBPAYMENTGATEWAY.startPayment(this.selectedBanklinkSource);
};

// Add/remove highlighting to the bank payment options
SEBPAYMENTGATEWAY.toggleBankOptionHighlighting = function (error = false) {
    let bankPaymentOptions = document.querySelectorAll('.sebpaymentgateway .banklink_input_label');
    if (bankPaymentOptions.length > 0) {
        for (let option of bankPaymentOptions) {
            if (error) {
                option.classList.add('error');
            } else {
                option.classList.remove('error');
            }
        }
    }
}

SEBPAYMENTGATEWAY.isApplePayAvailable = function () {
    $.ajax({
        url: "?fc=module&module=sebpaymentgateway&controller=accountinfo",
        dataType: "json",
        method: "GET",
        success: function (data) {
            let paymentMethods = data["payment_methods"];
            for (let i = 0; i < paymentMethods.length; i++) {
                if (paymentMethods[i]["source"] === "card") {
                    if (paymentMethods[i]["applepay_custom_available"] === true) {
                        if (window.ApplePaySession && ApplePaySession.canMakePayments()) {
                            let applePayButton = document.getElementById('apple-pay-button');
                            if (!applePayButton.onclick) {
                                applePayButton.addEventListener('click', async function () {
                                    await SEBPAYMENTGATEWAY.applePayChangeCursor();
                                    setTimeout(function() {
                                        SEBPAYMENTGATEWAY.applePayClick();
                                    }, 500);
                                });
                            }
                        } else {
                            SEBPAYMENTGATEWAY.removeApplePayButton();
                        }
                    } else {
                        SEBPAYMENTGATEWAY.removeApplePayButton();
                    }
                }
            }
        },
        error: function () {
            SEBPAYMENTGATEWAY.removeApplePayButton();
        }
    });
};

SEBPAYMENTGATEWAY.applePayChangeCursor = async function () {
    let applePayButton = document.getElementById('apple-pay-button');
    document.body.style.cursor = 'progress';
    applePayButton.style.cursor = 'progress';
    applePayButton.disabled = true;
};

SEBPAYMENTGATEWAY.removeApplePayButton = function () {
    let applePayButton = document.getElementById('apple-pay-button');
    let previousSibling = applePayButton.parentNode.previousElementSibling;
    if (previousSibling) {
        previousSibling.remove();
    }
    applePayButton.parentElement.remove();
};

SEBPAYMENTGATEWAY.applePayClick = function () {
    let applePayButton = document.getElementById('apple-pay-button');
    if (!SEBPAYMENTGATEWAY.areTermsAccepted()) {
        document.body.style.cursor = 'auto';
        applePayButton.style.cursor = 'pointer';
        applePayButton.disabled = false;
        return;
    }
    let requestData = {
        payment_method: 'apple_pay'
    };

    try {
        let oneoff = $.ajax({
            url: "/?fc=module&module=sebpaymentgateway&controller=validation&response_type=json",
            dataType: "json",
            data: requestData,
            method: "POST",
            async: false,
        });
        SEBPAYMENTGATEWAY.startApplePaySession(oneoff.responseJSON);
    } catch (error) {
        document.body.style.cursor = 'auto';
        applePayButton.style.cursor = 'pointer';
        applePayButton.disabled = false;
        return;
    }

    setTimeout(function() {
        document.body.style.cursor = 'auto';
        applePayButton.style.cursor = 'pointer';
        applePayButton.disabled = false;
    }, 1500);
};

SEBPAYMENTGATEWAY.startApplePaySession = function (oneoff) {
    if (window.ApplePaySession && ApplePaySession.canMakePayments()) {
        let store_name = document.getElementById('store-name').value;
        let applePayClient = ApplePayClient.initialize({
            access_token: oneoff.mobile_access_token,
            api_username: oneoff.api_username,
            merchant_id:  oneoff.applepay_merchant_identifier,
            account_name: oneoff.account_name,
        });
        applePayClient.createApplePayPayment({
            payment_reference: oneoff.payment_reference,
            country_code: oneoff.descriptor_country,
            currency_code: oneoff.currency,
            payment_link: oneoff.payment_link,
            total: {
                label: store_name,
                amount: oneoff.initial_amount,
            }
        });
    } else {
        return;
    }
};

var shrinkIframe = function(iframe, iframe_data) {
   iframe.css(iframe_data);
   jQuery("#dimmed_background_box").remove();
};
var expandIframe = function() {
    var iframe_data = {
        position: iframe.attr("position") || "static",
        top: iframe.position().top,
        left: iframe.position().left,
        width: iframe.width(),
        height: iframe.height(),
        zIndex: iframe.attr("zIndex"),
        marginLeft: iframe.attr("marginLeft"),
        marginRight: iframe.attr("marginRight")
    };

    jQuery('body').append("<div id='dimmed_background_box'></div>");
    jQuery('#dimmed_background_box').css({
        height:'100%',
        width:'100%',
        position:'fixed',
        top:0,
        left:0,
        zIndex:9998,
        backgroundColor:'#000000',
        opacity:0.5
    });

    var window_height = jQuery(window).height();
    var window_width = jQuery(window).width();

    if (window_width < 960) {
        iframe.css({ height:window_height,width:window_width,top:0 });
    } else {
        iframe.css({ height:640,width:960,top:(window_height-640)/2 });
    }
    iframe.css({ position:'fixed',zIndex:9999,margin:'auto' });
    return iframe_data;
};

var shrinked_iframe_data;
//var iframe = $('#sebpaymentgatewayIframe'); // iframe selector should be used

window.addEventListener('message', function(event) {
    if (!event.data){
        return;
    }

    var message = null;

    if (typeof event.data === 'object'){
        message = event.data;
    } else {
        message = JSON.parse(event.data);
    }

    if (!message){
        return;
    }

   /*
   1. An "expand" message is sent from the iframe page when 3D secure page is going to be displayed.
       The size of the iframe should be adjusted to hold 3D secure page
   2. A "shrink" message is sent from the iframe page when a user has provided authorisation details on the 3D secure page.
       The size of the iframe should be set to the initial values
   */
   if (message.resize_iframe == "expand") {
      shrinked_iframe_data = expandIframe(iframe);
   } else if (message.resize_iframe == "shrink") {
      shrinkIframe(iframe, shrinked_iframe_data);
   }

   if (message.transaction_result) {
         if (message.transaction_result == "completed") {
            window.location=$('#sebpaymentgatewayIframe').attr("target-url")+"?fc=module&module=sebpaymentgateway&controller=return&order_reference="+SEBPAYMENTGATEWAY.order_reference+"&transaction_result="+message.transaction_result;
         } else {
            if (SEBPAYMENTGATEWAY.iframeVisible) {
               $('#sebpaymentgatewayRetryButton').show();
            } else {
               SEBPAYMENTGATEWAY.openIframe();
               $('#sebpaymentgatewayRetryButton').show();
            }
         }
   }
}, false);

function var_dump(obj, alert) {
      var out = '';
      for (var i in obj) {
            out += i + ": " + obj[i] + "\n";
      }
      if (alert) alert(out);
      return out;
}
